# 今日话语-TodayDiscourse
## 简介
今日所想，一句话语，即可概括。  
今日话语是一款基于[CPython](https://www.python.org/)的一言API，可以在被调用时从词库中获取每日一句。

## 部署
首先，你需要安装Python3.11+。
在安装后，打开命令行，运行下面的命令：
```bash
pip install TodayDiscourse
todaydiscourse [port（端口）]
```

## 调用
使用GET请求或直接访问API部署网站的地址即可获取今日一言。   
更多高阶用法，请前往[官方文档](https://xinghetechnology.github.io/apis/todaydiscourse/)

## 鸣谢
感谢[VScode](https://code.visualstudio.com/)提供的免费开发环境。  
感谢[GitHub](https://github.com)提供的免费代码托管服务。  
感谢[CPython](https://python.org/)的免费编程语言。